@@ -169,7 +169,7 @@ def PrLightPurple(skk):
 
 #--------------------------------
 
-@click.command()
+@click.group()
 def main():
     """Traslation of DocFX source code"""
     init()
@@ -198,7 +198,7 @@ def main():
     # option = input(' Digite uma opção:\n [1] para traduzir arquivos modificados desde o último commit,\n [2] para traduzir todo o projeto, ou\n [Enter] para sair: ')
 
     @click.command()
-    def translatediff():
+    def diff():
         if workTree:
             PrYellow('\n The following files will be added or overwritten in target languages:')
             for doc in workTree:
@@ -234,7 +234,7 @@ def main():
         time.sleep(1)
 
     @click.command()
-    def translateall():
+    def all():
         global processed
         global greenFlag
         while not processed:
